@@ -15,7 +15,6 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_iot1click_devices.paginator import ListDeviceEventsPaginator, ListDevicesPaginator
@@ -42,6 +41,14 @@ else:
 __all__ = ("IoT1ClickDevicesServiceClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     ClientError: Type[BotocoreClientError]
     ForbiddenException: Type[BotocoreClientError]
@@ -55,7 +62,7 @@ class Exceptions:
 
 class IoT1ClickDevicesServiceClient:
     """
-    [IoT1ClickDevicesService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client)
+    [IoT1ClickDevicesService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client)
     """
 
     meta: ClientMeta
@@ -63,24 +70,24 @@ class IoT1ClickDevicesServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.can_paginate)
         """
 
     def claim_devices_by_claim_code(self, ClaimCode: str) -> ClaimDevicesByClaimCodeResponseTypeDef:
         """
-        [Client.claim_devices_by_claim_code documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.claim_devices_by_claim_code)
+        [Client.claim_devices_by_claim_code documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.claim_devices_by_claim_code)
         """
 
     def describe_device(self, DeviceId: str) -> DescribeDeviceResponseTypeDef:
         """
-        [Client.describe_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.describe_device)
+        [Client.describe_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.describe_device)
         """
 
     def finalize_device_claim(
         self, DeviceId: str, Tags: Dict[str, str] = None
     ) -> FinalizeDeviceClaimResponseTypeDef:
         """
-        [Client.finalize_device_claim documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.finalize_device_claim)
+        [Client.finalize_device_claim documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.finalize_device_claim)
         """
 
     def generate_presigned_url(
@@ -91,17 +98,17 @@ class IoT1ClickDevicesServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.generate_presigned_url)
         """
 
     def get_device_methods(self, DeviceId: str) -> GetDeviceMethodsResponseTypeDef:
         """
-        [Client.get_device_methods documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.get_device_methods)
+        [Client.get_device_methods documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.get_device_methods)
         """
 
     def initiate_device_claim(self, DeviceId: str) -> InitiateDeviceClaimResponseTypeDef:
         """
-        [Client.initiate_device_claim documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.initiate_device_claim)
+        [Client.initiate_device_claim documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.initiate_device_claim)
         """
 
     def invoke_device_method(
@@ -111,7 +118,7 @@ class IoT1ClickDevicesServiceClient:
         DeviceMethodParameters: str = None,
     ) -> InvokeDeviceMethodResponseTypeDef:
         """
-        [Client.invoke_device_method documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.invoke_device_method)
+        [Client.invoke_device_method documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.invoke_device_method)
         """
 
     def list_device_events(
@@ -123,39 +130,39 @@ class IoT1ClickDevicesServiceClient:
         NextToken: str = None,
     ) -> ListDeviceEventsResponseTypeDef:
         """
-        [Client.list_device_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_device_events)
+        [Client.list_device_events documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_device_events)
         """
 
     def list_devices(
         self, DeviceType: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListDevicesResponseTypeDef:
         """
-        [Client.list_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_devices)
+        [Client.list_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_devices)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.list_tags_for_resource)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.tag_resource)
         """
 
     def unclaim_device(self, DeviceId: str) -> UnclaimDeviceResponseTypeDef:
         """
-        [Client.unclaim_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.unclaim_device)
+        [Client.unclaim_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.unclaim_device)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.untag_resource)
         """
 
     def update_device_state(self, DeviceId: str, Enabled: bool = None) -> Dict[str, Any]:
         """
-        [Client.update_device_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.update_device_state)
+        [Client.update_device_state documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Client.update_device_state)
         """
 
     @overload
@@ -163,11 +170,11 @@ class IoT1ClickDevicesServiceClient:
         self, operation_name: Literal["list_device_events"]
     ) -> ListDeviceEventsPaginator:
         """
-        [Paginator.ListDeviceEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
+        [Paginator.ListDeviceEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDeviceEvents)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_devices"]) -> ListDevicesPaginator:
         """
-        [Paginator.ListDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
+        [Paginator.ListDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.56/reference/services/iot1click-devices.html#IoT1ClickDevicesService.Paginator.ListDevices)
         """
